==> humhub-1.11.3.tar.gz: humhub-1.11.3/protected/humhub/modules/comment/messages/fr/base.php <==
<?php
return array (
  '<strong>Confirm</strong> comment deleting' => '<strong>Confirmer</strong> la suppression du commentaire',
  '<strong>Delete</strong> comment?' => '<strong>Supprimer</strong> le commentaire ?',
  '<strong>Permalink</strong> to this comment' => '<strong>Permalien</strong> vers ce commentaire',
  'Cancel' => 'Annuler',
  'Cancel Edit' => 'Annuler la modification',
  'Comment' => 'Commentaire',
  'Comment could not be saved!' => 'Le commentaire ne peut être enregistré !',
  'Comment has been deleted' => 'Le commentaire a été supprimé.',
  'Comment of blocked user.' => 'Commentaire d’utilisateur ou utilisatrice bloqué·e.',
  'Comments' => 'Commentaires',
  'Confirm' => 'Confirmer',
  'Delete' => 'Supprimer',
  'Do you really want to delete this comment?' => 'Souhaitez-vous vraiment supprimer ce commentaire ?',
  'Edit' => 'Modifier',
  'Edit your comment...' => 'Modifier votre commentaire…',
  'Permalink' => 'Permalien',
  'Read full comment...' => 'Lire le commentaire complet…',
  'Reason' => 'Raison',
  'Reply' => 'Répondre',
  'Send a notification to author' => 'Envoyer une notification à l’auteur·e',
  'Show' => 'Montrer',
  'Show all {total} comments' => 'Afficher les commentaires précédents',
  'Show {count} more comments' => 'Afficher {count,plural,=1{le commentaire restant} other{# autres commentaires}}',
  'The comment must not be empty!' => 'Le commentaire ne doit pas être vide !',
  'Whenever a new comment was written.' => 'Chaque fois qu\'un nouveau commentaire a été écrit.',
  'Write a new comment...' => 'Écrire un commentaire…',
  'Write a new reply...' => 'Écrire une réponse…',
  'comment' => 'le commentaire',
  '{displayName} wrote a new comment ' => '{displayName} a écrit un commentaire',
);

==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/comment/messages/fr/base.php <==
<?php
return array (
  '<strong>Confirm</strong> comment deleting' => '<strong>Confirmer</strong> la suppression du commentaire',
  '<strong>Delete</strong> comment?' => '<strong>Supprimer</strong> le commentaire ?',
  '<strong>Permalink</strong> to this comment' => '<strong>Permalien</strong> vers ce commentaire',
  'Cancel' => 'Annuler',
  'Cancel Edit' => 'Annuler la modification',
  'Comment' => 'Commentaire',
  'Comment could not be saved!' => 'Le commentaire ne peut être enregistré !',
  'Comment has been deleted' => 'Le commentaire a été supprimé.',
  'Comment of blocked user.' => 'Commentaire d’utilisateur ou utilisatrice bloqué·e.',
  'Comments' => 'Commentaires',
  'Confirm' => 'Confirmer',
  'Delete' => 'Supprimer',
  'Do you really want to delete this comment?' => 'Souhaitez-vous vraiment supprimer ce commentaire ?',
  'Edit' => 'Modifier',
  'Edit your comment...' => 'Modifier votre commentaire…',
  'Permalink' => 'Permalien',
  'Read full comment...' => 'Lire le commentaire complet…',
  'Reason' => 'Raison',
  'Reply' => 'Répondre',
  'Send a notification to author' => 'Envoyer une notification à l’auteur·e',
  'Show' => 'Montrer',
  'Show all {total} comments' => 'Afficher les {total} commentaires précédents',
  'Show {count} more comments' => 'Afficher {count,plural,=1{le commentaire restant} other{# autres commentaires}}',
  'The comment must not be empty!' => 'Le commentaire ne doit pas être vide !',
  'Whenever a new comment was written.' => 'Chaque fois qu\'un nouveau commentaire a été écrit.',
  'Write a new comment...' => 'Écrire un commentaire…',
  'Write a new reply...' => 'Écrire une réponse…',
  'comment' => 'le commentaire',
  '{displayName} wrote a new comment ' => '{displayName} a écrit un commentaire',
);
